@@ -91,10 +91,6 @@ private Q_SLOTS:
      * Emit WindowUnregistered signal over bus
      */
     void slotWindowUnregistered(WId id);
-    /**
-     * Update window importer
-     */
-    void slotUpdateImporter(WId id);
     /**
      * Open a action in current menu
      */
@@ -112,9 +108,9 @@ private Q_SLOTS:
      */
     void slotCurrentScreenChanged();
     /**
-     * Delete obsolete importers
+     * Resize menubar
      */
-    void slotDeleteImporters();
+    void slotBarNeedResize();
     /**
      * Reconfigure module
      */
@@ -124,15 +120,15 @@ private:
     /**
      * return an importer for window id
      */
-    KDBusMenuImporter* getImporter(WId id, bool cached = true);
+    KDBusMenuImporter* getImporter(WId id);
     /**
-     * Show top menubar with menu
+     * Show menubar and update it with menu
      */
-    void showTopMenuBar(QMenu *menu);
+    void showMenuBar(QMenu *menu);
     /**
-     * Hide menubar. Delete object
+     * Hide menubar
      */
-    void hideMenubar(TopMenuBar* menubar);
+    void hideMenubar();
     /**
      * Return current screen
      */
@@ -146,12 +142,10 @@ private:
     MenuImporter* m_menuImporter;
     AppmenuDBus* m_appmenuDBus;
     QHash<WId, KDBusMenuImporter*> m_importers;
-    QList<KDBusMenuImporter*> m_oldImporters; // Only delete old importers when we are sure it's safe
     GtkIcons m_icons;
     QString m_menuStyle;
     TopMenuBar* m_menubar;
     VerticalMenu* m_menu;
-    QTimer* m_menuTimer;
     QTimer* m_screenTimer;
     QAction *m_waitingAction;
     int m_currentScreen;
