@@ -406,12 +406,16 @@ int activateVT(int vt);
 #ifndef _POSIX_MONOTONIC_CLOCK
 # define _POSIX_MONOTONIC_CLOCK -1
 #endif
-#if (_POSIX_MONOTONIC_CLOCK > 0)
-# define nowMonotonic 1
-#elif (_POSIX_MONOTONIC_CLOCK < 0)
+#if (_POSIX_MONOTONIC_CLOCK < 0)
 # define nowMonotonic 0
+# define nowWallDelta 0
 #else
+# if (_POSIX_MONOTONIC_CLOCK > 0)
+#  define nowMonotonic 1
+# else
 extern int nowMonotonic;
+# endif
+extern time_t nowWallDelta;
 #endif
 void updateNow(void);
 
