@@ -27,7 +27,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <kwineffects.h>
 
-#include <klocale.h>
+#include <KDE/KLocalizedString>
 #include <kdebug.h>
 
 namespace KWin
