@@ -1557,6 +1557,8 @@ void Toplevel::propertyNotifyEvent(XPropertyEvent* e)
             getShadow();
         else if (e->atom == atoms->net_wm_opaque_region)
             getWmOpaqueRegion();
+        else if (e->atom == atoms->kde_skip_close_animation)
+            getSkipCloseAnimation();
         break;
     }
     emit propertyNotify(this, e->atom);
