@@ -2,7 +2,7 @@
 KWin - the KDE window manager
 This file is part of the KDE project.
 
-Copyright (C) 2009 Martin Gräßlin <kde@martin-graesslin.com>
+Copyright (C) 2009 Martin Gräßlin <mgraesslin@kde.org>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -36,9 +36,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <KServiceTypeTrader>
 #include <KShortcutsEditor>
 
-#ifdef Q_WS_X11
 #include <QX11Info>
-#endif
 
 #include <netwm.h>
 
@@ -91,39 +89,19 @@ void KWinDesktopConfig::init()
     m_switchDesktopCollection->setConfigGlobal(true);
 
     // actions for switch desktop collection - other action is filled dynamically
-    KAction* a = qobject_cast<KAction*>(m_switchDesktopCollection->addAction("Switch to Next Desktop"));
-    a->setProperty("isConfigurationAction", true);
-    a->setText(i18n("Switch to Next Desktop"));
-    a->setGlobalShortcut(KShortcut(), KAction::ActiveShortcut);
-
-    a = qobject_cast<KAction*>(m_switchDesktopCollection->addAction("Switch to Previous Desktop"));
-    a->setProperty("isConfigurationAction", true);
-    a->setText(i18n("Switch to Previous Desktop"));
-    a->setGlobalShortcut(KShortcut(), KAction::ActiveShortcut);
-
-    a = qobject_cast<KAction*>(m_switchDesktopCollection->addAction("Switch One Desktop to the Right"));
-    a->setProperty("isConfigurationAction", true);
-    a->setText(i18n("Switch One Desktop to the Right"));
-    a->setGlobalShortcut(KShortcut(), KAction::ActiveShortcut);
-
-    a = qobject_cast<KAction*>(m_switchDesktopCollection->addAction("Switch One Desktop to the Left"));
-    a->setProperty("isConfigurationAction", true);
-    a->setText(i18n("Switch One Desktop to the Left"));
-    a->setGlobalShortcut(KShortcut(), KAction::ActiveShortcut);
-
-    a = qobject_cast<KAction*>(m_switchDesktopCollection->addAction("Switch One Desktop Up"));
-    a->setProperty("isConfigurationAction", true);
-    a->setText(i18n("Switch One Desktop Up"));
-    a->setGlobalShortcut(KShortcut(), KAction::ActiveShortcut);
-
-    a = qobject_cast<KAction*>(m_switchDesktopCollection->addAction("Switch One Desktop Down"));
-    a->setProperty("isConfigurationAction", true);
-    a->setText(i18n("Switch One Desktop Down"));
-    a->setGlobalShortcut(KShortcut(), KAction::ActiveShortcut);
+    addAction("Switch to Next Desktop", i18n("Switch to Next Desktop"));
+    addAction("Switch to Previous Desktop", i18n("Switch to Previous Desktop"));
+    addAction("Switch One Desktop to the Right", i18n("Switch One Desktop to the Right"));
+    addAction("Switch One Desktop to the Left", i18n("Switch One Desktop to the Left"));
+    addAction("Switch One Desktop Up", i18n("Switch One Desktop Up"));
+    addAction("Switch One Desktop Down", i18n("Switch One Desktop Down"));
+    addAction("Walk Through Desktops", i18n("Walk Through Desktops"));
+    addAction("Walk Through Desktops (Reverse)", i18n("Walk Through Desktops (Reverse)"));
+    addAction("Walk Through Desktop List", i18n("Walk Through Desktop List"));
+    addAction("Walk Through Desktop List (Reverse)", i18n("Walk Through Desktop List (Reverse)"));
 
     m_editor->addCollection(m_switchDesktopCollection, i18n("Desktop Switching"));
 
-#ifdef Q_WS_X11
     // get number of desktops
     NETRootInfo info(QX11Info::display(), NET::NumberOfDesktops | NET::DesktopNames);
     int n = info.numberOfDesktops();
@@ -141,7 +119,6 @@ void KWinDesktopConfig::init()
     m_ui->numberSpinBox->setValue(n);
 
     m_editor->addCollection(m_actionCollection, i18n("Desktop Switching"));
-#endif
 
     // search the effect names
     // TODO: way to recognize if a effect is not found
@@ -186,11 +163,7 @@ void KWinDesktopConfig::init()
     connect(m_ui->effectConfigButton, SIGNAL(clicked()), SLOT(slotConfigureEffectClicked()));
 
     // Begin check for immutable - taken from old desktops kcm
-#ifdef Q_WS_X11
     int kwin_screen_number = DefaultScreen(QX11Info::display());
-#else
-    int kwin_screen_number = 0;
-#endif
 
     m_config = KSharedConfig::openConfig("kwinrc");
 
@@ -223,6 +196,14 @@ KWinDesktopConfig::~KWinDesktopConfig()
     undo();
 }
 
+void KWinDesktopConfig::addAction(const QString &name, const QString &label)
+{
+    KAction* a = qobject_cast<KAction*>(m_switchDesktopCollection->addAction(name));
+    a->setProperty("isConfigurationAction", true);
+    a->setText(label);
+    a->setGlobalShortcut(KShortcut(), KAction::ActiveShortcut);
+}
+
 void KWinDesktopConfig::defaults()
 {
     // TODO: plasma stuff
@@ -256,7 +237,6 @@ void KWinDesktopConfig::load()
     // This method is called on reset(). So undo all changes.
     undo();
 
-#ifdef Q_WS_X11
     // get number of desktops
     unsigned long properties[] = {NET::NumberOfDesktops | NET::DesktopNames, NET::WM2DesktopLayout };
     NETRootInfo info(QX11Info::display(), properties, 2);
@@ -267,7 +247,6 @@ void KWinDesktopConfig::load()
         m_ui->desktopNames->setName(i, name);
     }
     m_ui->rowsSpinBox->setValue(info.desktopLayoutColumnsRows().height());
-#endif
 
     // Popup info
     KConfigGroup effectconfig(m_config, "Plugins");
@@ -306,7 +285,6 @@ void KWinDesktopConfig::load()
 void KWinDesktopConfig::save()
 {
     // TODO: plasma stuff
-#ifdef Q_WS_X11
     unsigned long properties[] = {NET::NumberOfDesktops | NET::DesktopNames, NET::WM2DesktopLayout };
     NETRootInfo info(QX11Info::display(), properties, 2);
     // set desktop names
@@ -342,7 +320,6 @@ void KWinDesktopConfig::save()
         groupname.sprintf("Desktops-screen-%d", screenNumber);
     KConfigGroup group(m_config, groupname);
     group.writeEntry("Rows", rows);
-#endif
 
     // Popup info
     KConfigGroup effectconfig(m_config, "Plugins");
