@@ -31,6 +31,8 @@ DEALINGS IN THE SOFTWARE.
 #include <klocale.h>
 #include <klibrary.h>
 #include <kconfiggroup.h>
+#include <KDE/KLocalizedString>
+#include <KDE/KGlobal>
 #include <assert.h>
 
 #include <QDir>
@@ -90,6 +92,11 @@ KDecorationFactory* KDecorationPlugins::factory()
     return fact;
 }
 
+const KDecorationFactory *KDecorationPlugins::factory() const
+{
+    return fact;
+}
+
 // convenience
 KDecoration* KDecorationPlugins::createDecoration(KDecorationBridge* bridge)
 {
