@@ -110,13 +110,18 @@ static xcb_render_picture_t createPicture(xcb_pixmap_t pix, int depth)
 XRenderPicture::XRenderPicture(const QPixmap &pix)
 {
     if (Extensions::nonNativePixmaps()) {
-        XRenderPicture(pix.toImage());
+        fromImage(pix.toImage());
     } else {
         d = new XRenderPictureData(createPicture(pix.handle(), pix.depth()));
     }
 }
 
 XRenderPicture::XRenderPicture(const QImage &img)
+{
+    fromImage(img);
+}
+
+void XRenderPicture::fromImage(const QImage &img)
 {
     const int depth = img.depth();
     xcb_pixmap_t xpix = xcb_generate_id(connection());
