@@ -28,6 +28,7 @@ DEALINGS IN THE SOFTWARE.
 #include "client.h"
 #include "deleted.h"
 #include "effects.h"
+#include <kwinglplatform.h>
 #include <kwinglutils.h>
 #include <kwinxrenderutils.h>
 #include <kdebug.h>
@@ -310,21 +311,12 @@ void ImageBasedPaintRedirector::discardScratch()
 // ------------------------------------------------------------------
 
 
-
-unsigned int OpenGLPaintRedirector::s_count = 0;
-unsigned int OpenGLPaintRedirector::s_fbo = 0;
-
 OpenGLPaintRedirector::OpenGLPaintRedirector(Client *c, QWidget *widget)
     : ImageBasedPaintRedirector(c, widget)
 {
-    s_count++;
-
     for (int i = 0; i < TextureCount; ++i)
         m_textures[i] = NULL;
 
-    if (!s_fbo && GLRenderTarget::supported())
-        glGenFramebuffers(1, &s_fbo);
-
     PaintRedirector::resizePixmaps();
 }
 
@@ -332,12 +324,6 @@ OpenGLPaintRedirector::~OpenGLPaintRedirector()
 {
     for (int i = 0; i < TextureCount; ++i)
         delete m_textures[i];
-
-    // Delete the FBO if this is the last OpenGLPaintRedirector
-    if (--s_count == 0 && s_fbo) {
-        glDeleteFramebuffers(1, &s_fbo);
-        s_fbo = 0;
-    }
 }
 
 void OpenGLPaintRedirector::resizePixmaps(const QRect *rects)
@@ -355,8 +341,6 @@ void OpenGLPaintRedirector::resizePixmaps(const QRect *rects)
         }
     }
 
-    bool fbo_bound = false;
-
     for (int i = 0; i < 2; i++) {
         if (m_textures[i] && m_textures[i]->size() == size[i])
             continue;
@@ -370,22 +354,8 @@ void OpenGLPaintRedirector::resizePixmaps(const QRect *rects)
         m_textures[i] = new GLTexture(size[i].width(), size[i].height());
         m_textures[i]->setYInverted(true);
         m_textures[i]->setWrapMode(GL_CLAMP_TO_EDGE);
-
-        if (s_fbo) {
-            // Clear the texture
-            if (!fbo_bound) {
-                glBindFramebuffer(GL_FRAMEBUFFER, s_fbo);
-                glClearColor(0, 0, 0, 0);
-                fbo_bound = true;
-            }
-
-            glFramebufferTexture2D(GL_FRAMEBUFFER, GL_COLOR_ATTACHMENT0, GL_TEXTURE_2D, m_textures[i]->texture(), 0);
-            glClear(GL_COLOR_BUFFER_BIT);
-        }
+        m_textures[i]->clear();
     }
-
-    if (fbo_bound)
-        glBindFramebuffer(GL_FRAMEBUFFER, 0);
 }
 
 void OpenGLPaintRedirector::preparePaint(const QPixmap &pending)
