@@ -56,7 +56,8 @@ class Tasks : public Plasma::Applet
 
     protected:
         void createConfigurationInterface(KConfigDialog *parent);
-        QSizeF sizeHint(Qt::SizeHint which, const QSizeF & constraint = QSizeF()) const;
+        QSizeF sizeHint(Qt::SizeHint which, const QSizeF &constraint = QSizeF()) const;
+        void contextMenuEvent(QGraphicsSceneContextMenuEvent *event);
 
     private slots:
         void activateItem(int id, bool toggle);
@@ -65,6 +66,7 @@ class Tasks : public Plasma::Applet
         void itemMove(int id, int newIndex);
         void itemGeometryChanged(int id, int x, int y, int width, int height);
         void itemNeedsAttention(bool needs);
+        void presentWindows(int groupParentId);
 
         void handleActiveWindowChanged(WId activeWindow);
 
