@@ -383,7 +383,7 @@ PolicyAgent::RequiredPolicies PolicyAgent::requirePolicyCheck(PolicyAgent::Requi
         QDBusPendingReply< bool > rp = m_ckSessionInterface.data()->asyncCall("IsActive");
         rp.waitForFinished();
 
-        if (!rp.value() && !m_wasLastActiveSession) {
+        if (!(rp.isValid() && rp.value()) && !m_wasLastActiveSession) {
             return policies;
         }
     }
